@@ -16,7 +16,7 @@ use Carp;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(pingecho);
-$VERSION = "2.34";
+$VERSION = "2.39";
 
 sub SOL_IP { 0; };
 sub IP_TOS { 1; };
@@ -35,11 +35,20 @@ $syn_forking = 0;
 if ($^O =~ /Win32/i) {
   # Hack to avoid this Win32 spewage:
   # Your vendor has not defined POSIX macro ECONNREFUSED
-  *ECONNREFUSED = sub() {10061;}; # "Unknown Error" Special Win32 Response?
-  *ENOTCONN     = sub() {10057;};
-  *ECONNRESET   = sub() {10054;};
-  *EINPROGRESS  = sub() {10036;};
-  *EWOULDBLOCK  = sub() {10035;};
+  my @pairs = (ECONNREFUSED => 10061, # "Unknown Error" Special Win32 Response?
+	       ENOTCONN     => 10057,
+	       ECONNRESET   => 10054,
+	       EINPROGRESS  => 10036,
+	       EWOULDBLOCK  => 10035,
+	  );
+  while (my $name = shift @pairs) {
+    my $value = shift @pairs;
+    # When defined, these all are non-zero
+    unless (eval $name) {
+      no strict 'refs';
+      *{$name} = defined prototype \&{$name} ? sub () {$value} : sub {$value};
+    }
+  }
 #  $syn_forking = 1;    # XXX possibly useful in < Win2K ?
 };
 
@@ -1365,6 +1374,8 @@ sub close
     delete $self->{"syn"};
   } elsif ($self->{"proto"} eq "tcp") {
     # The connection will already be closed
+  } elsif ($self->{"proto"} eq "external") {
+    # Nothing to close
   } else {
     $self->{"fh"}->close();
   }
@@ -1536,7 +1547,7 @@ be 1 if the host is reachable and 0 if it is not.  For most practical
 purposes, undef and 0 and can be treated as the same case.  In array
 context, the elapsed time as well as the string form of the ip the
 host resolved to are also returned.  The elapsed time value will
-be a float, as retuned by the Time::HiRes::time() function, if hires()
+be a float, as returned by the Time::HiRes::time() function, if hires()
 has been previously called, otherwise it is returned as an integer.
 
 =item $p->source_verify( { 0 | 1 } );
@@ -1763,6 +1774,4 @@ Copyright (c) 2001, Colin McMillen.  All rights reserved.
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-$Id: Ping.pm,v 1.86 2003/06/27 21:31:07 rob Exp $
-
 =cut
